aboutsummaryrefslogtreecommitdiff
path: root/loginutils/passwd.c
diff options
context:
space:
mode:
Diffstat (limited to 'loginutils/passwd.c')
-rw-r--r--loginutils/passwd.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/loginutils/passwd.c b/loginutils/passwd.c
index 3e1ef9abf..02303b575 100644
--- a/loginutils/passwd.c
+++ b/loginutils/passwd.c
@@ -52,7 +52,7 @@ static char* new_password(const struct passwd *pw, uid_t myuid, const char *algo
if (myuid != 0 && pw->pw_passwd[0]) {
char *encrypted;
- orig = bb_ask_stdin("Old password: "); /* returns ptr to static */
+ orig = bb_ask_noecho_stdin("Old password: "); /* returns ptr to static */
if (!orig)
goto err_ret;
encrypted = pw_encrypt(orig, pw->pw_passwd, 1); /* returns malloced str */
@@ -65,11 +65,11 @@ static char* new_password(const struct passwd *pw, uid_t myuid, const char *algo
if (ENABLE_FEATURE_CLEAN_UP)
free(encrypted);
}
- orig = xstrdup(orig); /* or else bb_ask_stdin() will destroy it */
- newp = bb_ask_stdin("New password: "); /* returns ptr to static */
+ orig = xstrdup(orig); /* or else bb_ask_noecho_stdin() will destroy it */
+ newp = bb_ask_noecho_stdin("New password: "); /* returns ptr to static */
if (!newp)
goto err_ret;
- newp = xstrdup(newp); /* we are going to bb_ask_stdin() again, so save it */
+ newp = xstrdup(newp); /* we are going to bb_ask_noecho_stdin() again, so save it */
if (ENABLE_FEATURE_PASSWD_WEAK_CHECK
&& obscure(orig, newp, pw)
&& myuid != 0
@@ -77,7 +77,7 @@ static char* new_password(const struct passwd *pw, uid_t myuid, const char *algo
goto err_ret; /* non-root is not allowed to have weak passwd */
}
- cp = bb_ask_stdin("Retype password: ");
+ cp = bb_ask_noecho_stdin("Retype password: ");
if (!cp)
goto err_ret;
if (strcmp(cp, newp) != 0) {